###############################
Siglent SDS1072CML Oscilloscope
###############################

.. autoclass:: pymeasure.instruments.siglenttechnologies.SDS1072CML
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.siglenttechnologies.siglent_sds1072cml.VoltageChannel
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.siglenttechnologies.siglent_sds1072cml.TriggerChannel
    :members:
    :show-inheritance:
